<?php
require_once 'config.php';
require_once 'db.php';

$input_raw = file_get_contents('php://input');
$input = json_decode($input_raw, true);

if (!$input) {
    http_response_code(400);
    echo "Datos inválidos";
    exit;
}

try {
    $db = Database::getInstance()->getConnection();
    $db->beginTransaction();

    $stmt = $db->prepare("SELECT id FROM customers WHERE name = ? AND contact = ?");
    $stmt->execute([$input['nombre'], $input['contacto']]);
    $cliente = $stmt->fetch();

    if ($cliente) {
        $clienteId = $cliente['id'];
    } else {
        $stmt = $db->prepare("INSERT INTO customers (name, contact, dni) VALUES (?, ?, ?)");
        $stmt->execute([$input['nombre'], $input['contacto'], $input['dni']]);
        $clienteId = $db->lastInsertId();
    }

    $stmt = $db->prepare("INSERT INTO credits (customer_id, product, total_amount, num_installments, outstanding_balance, start_date, liquidation_number)
                          VALUES (?, ?, ?, ?, ?, NOW(), ?)");
    $stmt->execute([
        $clienteId,
        $input['producto'],
        $input['total'],
        $input['cuotas'],
        $input['total'],
        $input['liquidation_number'] ?? null
    ]);
    $creditoId = $db->lastInsertId();

    $stmt = $db->prepare("INSERT INTO installments (credit_id, installment_number, due_date, amount, amount_paid, status) 
                          VALUES (?, ?, ?, ?, ?, 'pendiente')");

    foreach ($input['cuotasDetalle'] as $cuota) {
        $fecha = DateTime::createFromFormat('d/m/Y', $cuota['fecha']);
        if (!$fecha) $fecha = DateTime::createFromFormat('Y-m-d', $cuota['fecha']);
        if (!$fecha) continue;

        $stmt->execute([
            $creditoId,
            $cuota['numero'],
            $fecha->format('Y-m-d'),
            $cuota['monto'],
            0.00
        ]);
    }

    $db->commit();
    echo "OK";

} catch (Exception $e) {
    $db->rollBack();
    http_response_code(500);
    echo "Error interno";
}
?>
