<?php
require_once 'config.php';
require_once 'db.php';
require_once 'functions.php';

try {
    $db = Database::getInstance()->getConnection();

    // Si se solicita la descarga del CSV
    if (isset($_POST['export'])) {
        // Configurar headers para descarga
        header('Content-Type: text/csv; charset=utf-8');
        header('Content-Disposition: attachment; filename=creditos_' . date('Y-m-d') . '.csv');
        
        // Crear archivo CSV
        $output = fopen('php://output', 'w');
        
        // Escribir BOM para UTF-8
        fprintf($output, chr(0xEF).chr(0xBB).chr(0xBF));
        
        // Encabezados
        fputcsv($output, [
            'ID',
            'Cliente',
            'Contacto',
            'Monto Total',
            'Cuotas Totales',
            'Cuotas Pagadas',
            'Saldo Pendiente',
            'Fecha Inicio',
            'Estado',
            'Última Actualización'
        ]);
        
        // Obtener y escribir datos
        $query = "
            SELECT 
                c.id,
                cu.name as customer_name,
                cu.contact,
                c.total_amount,
                c.num_installments,
                (SELECT COUNT(*) FROM payments p WHERE p.credit_id = c.id) as payments_made,
                c.outstanding_balance,
                c.start_date,
                CASE 
                    WHEN c.outstanding_balance = 0 THEN 'Pagado'
                    ELSE 'Pendiente'
                END as status,
                c.updated_at
            FROM credits c
            JOIN customers cu ON c.customer_id = cu.id
            ORDER BY c.id DESC
        ";
        
        $stmt = $db->query($query);
        while ($row = $stmt->fetch()) {
            fputcsv($output, [
                $row['id'],
                $row['customer_name'],
                $row['contact'],
                $row['total_amount'],
                $row['num_installments'],
                $row['payments_made'],
                $row['outstanding_balance'],
                $row['start_date'],
                $row['status'],
                $row['updated_at']
            ]);
        }
        
        fclose($output);
        exit;
    }

    $pageTitle = "Exportar Datos";
    require_once 'templates/header.php';
?>

<div class="bg-white rounded-lg shadow-md p-6 max-w-2xl mx-auto">
    <div class="flex items-center justify-between mb-6">
        <h1 class="text-2xl font-semibold text-gray-800">
            <i class="fas fa-file-export mr-2"></i>Exportar Datos
        </h1>
        <a href="index.php" class="text-blue-500 hover:text-blue-600">
            <i class="fas fa-arrow-left mr-1"></i>Volver
        </a>
    </div>

    <div class="bg-blue-50 p-6 rounded-lg mb-6">
        <h2 class="text-lg font-medium text-blue-800 mb-4">
            <i class="fas fa-info-circle mr-2"></i>Información sobre la Exportación
        </h2>
        <div class="space-y-4 text-blue-700">
            <p>
                Al exportar los datos, obtendrá un archivo CSV que incluirá:
            </p>
            <ul class="list-disc list-inside ml-4 space-y-2">
                <li>Información de todos los créditos</li>
                <li>Datos de los clientes</li>
                <li>Estado de los pagos</li>
                <li>Saldos pendientes</li>
                <li>Fechas de inicio y última actualización</li>
            </ul>
            <p class="mt-4">
                Este archivo puede ser abierto con cualquier programa de hojas de cálculo 
                (Microsoft Excel, Google Sheets, LibreOffice Calc, etc.).
            </p>
        </div>
    </div>

    <form action="export.php" method="POST" class="space-y-6">
        <div class="bg-gray-50 p-6 rounded-lg">
            <h3 class="text-lg font-medium text-gray-800 mb-4">Opciones de Exportación</h3>
            <div class="space-y-4">
                <div class="flex items-center">
                    <input type="checkbox" 
                           id="include_completed" 
                           name="include_completed" 
                           checked
                           class="h-4 w-4 text-blue-600 focus:ring-blue-500 border-gray-300 rounded">
                    <label for="include_completed" class="ml-2 block text-sm text-gray-900">
                        Incluir créditos completados
                    </label>
                </div>
                <div class="flex items-center">
                    <input type="checkbox" 
                           id="include_payments" 
                           name="include_payments" 
                           checked
                           class="h-4 w-4 text-blue-600 focus:ring-blue-500 border-gray-300 rounded">
                    <label for="include_payments" class="ml-2 block text-sm text-gray-900">
                        Incluir historial de pagos
                    </label>
                </div>
            </div>
        </div>

        <div class="flex justify-end space-x-2">
            <a href="index.php" 
               class="px-4 py-2 border border-gray-300 rounded-md text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                Cancelar
            </a>
            <button type="submit" 
                    name="export" 
                    value="1"
                    class="px-4 py-2 border border-transparent rounded-md shadow-sm text-white bg-blue-600 hover:bg-blue-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                <i class="fas fa-download mr-1"></i> Exportar Datos
            </button>
        </div>
    </form>

    <div class="mt-8 p-4 bg-yellow-50 rounded-lg">
        <div class="flex">
            <div class="flex-shrink-0">
                <i class="fas fa-lightbulb text-yellow-400"></i>
            </div>
            <div class="ml-3">
                <h3 class="text-sm font-medium text-yellow-800">Consejo</h3>
                <div class="mt-2 text-sm text-yellow-700">
                    <p>
                        Se recomienda realizar exportaciones periódicas de los datos como medida de respaldo.
                        Puede utilizar el archivo exportado para:
                    </p>
                    <ul class="list-disc list-inside mt-2">
                        <li>Mantener un registro histórico</li>
                        <li>Realizar análisis en hojas de cálculo</li>
                        <li>Crear informes personalizados</li>
                        <li>Tener un respaldo de seguridad</li>
                    </ul>
                </div>
            </div>
        </div>
    </div>
</div>

<?php
    require_once 'templates/footer.php';
} catch (Exception $e) {
    error_log("Error en export.php: " . $e->getMessage());
    $errorMessage = "Ha ocurrido un error al exportar los datos. Por favor, intente nuevamente.";
    require_once 'templates/header.php';
    echo "<div class='bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4' role='alert'>
            <p class='font-bold'>Error</p>
            <p>$errorMessage</p>
          </div>";
    require_once 'templates/footer.php';
}
?>