<?php
require_once 'config.php';
require_once 'db.php';

session_start();
if (!isset($_SESSION['acceso_concedido'])) {
    if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['clave'])) {
        if ($_POST['clave'] === 'solo@') {
            $_SESSION['acceso_concedido'] = true;
            header("Location: index.php");
            exit;
        } else {
            $error = "Clave incorrecta";
        }
    }
    ?>
    <!DOCTYPE html>
    <html lang="es">
    <head>
        <meta charset="UTF-8">
        <title>Acceso</title>
        <style>
            body { font-family: Arial, sans-serif; background: #eef2f7; display: flex; justify-content: center; align-items: center; height: 100vh; }
            .login-box { background: white; padding: 30px; border-radius: 8px; box-shadow: 0 0 10px rgba(0,0,0,0.1); text-align: center; }
            input[type="password"] { padding: 10px; width: 100%; margin: 10px 0; border: 1px solid #ccc; border-radius: 4px; }
            button { background: #004a80; color: white; padding: 10px 20px; border: none; border-radius: 4px; cursor: pointer; }
            button:hover { background: #00345a; }
            .error { color: red; font-size: 14px; }
        </style>
    </head>
    <body>
        <div class="login-box">
            <img src="logo.jpg" alt="SoloTecno" style="max-height: 60px;"><br><br>
            <form method="post">
                <label for="clave">Ingresá la clave para acceder</label><br>
                <input type="password" name="clave" id="clave" required>
                <button type="submit">Entrar</button>
            </form>
            <?php if (isset($error)): ?><div class="error"><?= $error ?></div><?php endif; ?>
        </div>
    </body>
    </html>
    <?php
    exit;
}

$conn = new mysqli(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if ($conn->connect_error) {
    die("Conexión fallida: " . $conn->connect_error);
}

$sql = "
    SELECT cr.id, cu.name AS customer_name, cr.product, cr.total_amount,
           IFNULL(SUM(p.payment_amount), 0) AS total_pagado,
           (cr.total_amount - IFNULL(SUM(p.payment_amount), 0)) AS saldo_pendiente
    FROM credits cr
    JOIN customers cu ON cu.id = cr.customer_id
    LEFT JOIN payments p ON p.credit_id = cr.id
    GROUP BY cr.id
    ORDER BY cr.created_at DESC
";
$result = $conn->query($sql);

$sql_resumen = "
    SELECT COUNT(DISTINCT cr.id) AS cantidad_creditos,
           SUM(cr.total_amount) AS total_prestado,
           SUM(IFNULL(p.payment_amount, 0)) AS total_pagado
    FROM credits cr
    LEFT JOIN payments p ON p.credit_id = cr.id
";
$resumen = $conn->query($sql_resumen)->fetch_assoc();
$resumen['saldo_pendiente'] = $resumen['total_prestado'] - $resumen['total_pagado'];
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Panel de Créditos - SoloTecno</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
    <style>
        body { font-family: 'Segoe UI', sans-serif; background: #fafafa; margin: 0; padding: 0; color: #333; }
        header { background: #002a4d; color: white; padding: 15px; text-align: center; }
        header img { max-height: 50px; vertical-align: middle; }
        header h1 { display: inline-block; margin-left: 15px; vertical-align: middle; font-size: 24px; }
        nav {
            background: #004a80;
            padding: 10px;
            text-align: center;
            position: sticky;
            top: 0;
            z-index: 50;
        }
        nav a {
            color: white; text-decoration: none; margin: 0 10px;
            font-weight: 500; padding: 8px 15px; border-radius: 4px;
            background: #0066aa; display: inline-block;
        }
        nav a:hover { background: #00568c; }
        .container { padding: 20px; max-width: 1100px; margin: auto; }
        table {
            width: 100%; border-collapse: collapse; background: white; font-size: 14px;
        }
        th, td { padding: 8px; border-bottom: 1px solid #ddd; text-align: center; }
        th { background: #f5f5f5; color: #333; }
        .btn {
            padding: 5px 8px; background: #0066aa; color: white;
            text-decoration: none; border-radius: 4px; font-size: 12px;
            display: inline-block; margin: 2px;
        }
        .btn:hover { background: #004a80; }
        .btn-delete { background: #cc0000; }
        .btn-delete:hover { background: #990000; }
    </style>
    <script>
    function eliminarPrestamo(id) {
        if (confirm('¿Estás seguro de eliminar este préstamo y todas sus cuotas? Esta acción no se puede deshacer.')) {
            fetch('eliminar_prestamo.php', {
                method: 'POST',
                headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
                body: 'id=' + id
            })
            .then(response => response.text())
            .then(data => {
                if (data.trim() === 'OK') {
                    location.reload();
                } else {
                    alert("Error al eliminar: " + data);
                }
            });
        }
    }
    </script>
</head>
<body>
<header>
    <img src="logo.jpg" alt="SoloTecno">
    <h1>Panel de Créditos</h1>
</header>
<nav>
    <a href="index.php">Inicio</a>
    <a href="simulacion.html">Simular Crédito</a>
    <a href="reporte_mora.php">Cuotas Vencidas</a>
    <a href="list_overdue.php">Créditos en Mora</a>
</nav>
<div class="container">
    <h2>Listado de Créditos</h2>
    <table>
        <tr>
            <th>Cliente</th>
            <th>Producto</th>
            <th>Total</th>
            <th>Pagado</th>
            <th>Saldo</th>
            <th>Acciones</th>
        </tr>
        <?php while($row = $result->fetch_assoc()): ?>
        <tr>
            <td><?= htmlspecialchars($row['customer_name']) ?></td>
            <td><?= htmlspecialchars($row['product']) ?></td>
            <td>$<?= number_format($row['total_amount'], 2, ',', '.') ?></td>
            <td>$<?= number_format($row['total_pagado'], 2, ',', '.') ?></td>
            <td>$<?= number_format($row['saldo_pendiente'], 2, ',', '.') ?></td>
            <td>
                <a class="btn" href="detalle_credito.php?id=<?= $row['id'] ?>">Ver</a>
                <a class="btn" href="reporte_cliente_pdf.php?id=<?= $row['id'] ?>">PDF</a>
                <button class="btn btn-delete" onclick="eliminarPrestamo(<?= $row['id'] ?>)">Eliminar</button>
            </td>
        </tr>
        <?php endwhile; ?>
    </table>
</div>
</body>
</html>
