<?php
require_once 'config.php';
require_once 'db.php';
require_once 'functions.php';

$pageTitle = "Cuotas Atrasadas";

try {
    $db = Database::getInstance()->getConnection();
    
    // Calcular la fecha actual
    $today = date('Y-m-d');
    
    // Obtener créditos con pagos atrasados
    $query = "
        SELECT 
            c.id as credit_id,
            cu.name as customer_name,
            cu.contact as customer_contact,
            c.total_amount,
            c.num_installments,
            c.start_date,
            c.outstanding_balance,
            (SELECT COUNT(*) FROM payments p WHERE p.credit_id = c.id) as payments_made,
            DATEDIFF(NOW(), 
                DATE_ADD(c.start_date, 
                    INTERVAL (
                        (SELECT COUNT(*) FROM payments p WHERE p.credit_id = c.id) * 7
                    ) DAY
                )
            ) as days_overdue
        FROM credits c
        JOIN customers cu ON c.customer_id = cu.id
        WHERE c.outstanding_balance > 0
        HAVING days_overdue > 0
        ORDER BY days_overdue DESC
    ";
    
    $stmt = $db->query($query);
    $overdueCredits = $stmt->fetchAll();

    require_once 'templates/header.php';
?>

<div class="bg-white rounded-lg shadow-md p-6">
    <div class="flex justify-between items-center mb-6">
        <h1 class="text-2xl font-semibold text-gray-800">
            <i class="fas fa-clock mr-2"></i>Cuotas Atrasadas
        </h1>
        <div class="flex space-x-2">
            <button onclick="exportToExcel()" 
                    class="bg-green-500 hover:bg-green-600 text-white px-4 py-2 rounded-lg transition-colors">
                <i class="fas fa-file-excel mr-1"></i> Exportar a Excel
            </button>
            <a href="index.php" class="bg-blue-500 hover:bg-blue-600 text-white px-4 py-2 rounded-lg transition-colors">
                <i class="fas fa-home mr-1"></i> Inicio
            </a>
        </div>
    </div>

    <?php if (empty($overdueCredits)): ?>
        <div class="bg-green-50 border-l-4 border-green-500 p-4">
            <div class="flex">
                <div class="flex-shrink-0">
                    <i class="fas fa-check-circle text-green-500"></i>
                </div>
                <div class="ml-3">
                    <p class="text-sm text-green-700">
                        No hay cuotas atrasadas en este momento.
                    </p>
                </div>
            </div>
        </div>
    <?php else: ?>
        <div class="overflow-x-auto">
            <table class="min-w-full divide-y divide-gray-200" id="overdueTable">
                <thead class="bg-gray-50">
                    <tr>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Cliente</th>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Contacto</th>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Monto Total</th>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Cuotas Pagadas</th>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Saldo Pendiente</th>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Días de Atraso</th>
                        <th class="px-6 py-3 text-left text-xs font-medium text-gray-500 uppercase tracking-wider">Acciones</th>
                    </tr>
                </thead>
                <tbody class="bg-white divide-y divide-gray-200">
                    <?php foreach ($overdueCredits as $credit): ?>
                        <tr class="hover:bg-gray-50">
                            <td class="px-6 py-4 whitespace-nowrap">
                                <div class="text-sm font-medium text-gray-900">
                                    <?php echo htmlspecialchars($credit['customer_name']); ?>
                                </div>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap">
                                <div class="text-sm text-gray-500">
                                    <?php echo htmlspecialchars($credit['customer_contact']); ?>
                                </div>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap">
                                <div class="text-sm text-gray-900">
                                    <?php echo formatMoney($credit['total_amount']); ?>
                                </div>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap">
                                <div class="text-sm text-gray-900">
                                    <?php echo $credit['payments_made']; ?> de <?php echo $credit['num_installments']; ?>
                                </div>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap">
                                <div class="text-sm text-gray-900">
                                    <?php echo formatMoney($credit['outstanding_balance']); ?>
                                </div>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap">
                                <span class="px-2 inline-flex text-xs leading-5 font-semibold rounded-full 
                                           <?php echo $credit['days_overdue'] > 14 ? 'bg-red-100 text-red-800' : 'bg-yellow-100 text-yellow-800'; ?>">
                                    <?php echo $credit['days_overdue']; ?> días
                                </span>
                            </td>
                            <td class="px-6 py-4 whitespace-nowrap text-sm font-medium">
                                <div class="flex space-x-2">
                                    <a href="register_payment.php?credit_id=<?php echo $credit['credit_id']; ?>" 
                                       class="text-blue-600 hover:text-blue-900"
                                       title="Registrar Pago">
                                        <i class="fas fa-cash-register"></i>
                                    </a>
                                    <a href="edit_credit.php?id=<?php echo $credit['credit_id']; ?>" 
                                       class="text-green-600 hover:text-green-900"
                                       title="Editar Crédito">
                                        <i class="fas fa-edit"></i>
                                    </a>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- Resumen -->
        <div class="mt-6 bg-gray-50 rounded-lg p-4">
            <h2 class="text-lg font-medium text-gray-800 mb-4">Resumen</h2>
            <div class="grid grid-cols-1 md:grid-cols-3 gap-4">
                <div class="bg-white p-4 rounded-lg shadow">
                    <p class="text-sm text-gray-500">Total Créditos Atrasados</p>
                    <p class="text-2xl font-bold text-gray-900"><?php echo count($overdueCredits); ?></p>
                </div>
                <div class="bg-white p-4 rounded-lg shadow">
                    <p class="text-sm text-gray-500">Monto Total Pendiente</p>
                    <p class="text-2xl font-bold text-gray-900">
                        <?php 
                        $totalPending = array_sum(array_column($overdueCredits, 'outstanding_balance'));
                        echo formatMoney($totalPending);
                        ?>
                    </p>
                </div>
                <div class="bg-white p-4 rounded-lg shadow">
                    <p class="text-sm text-gray-500">Promedio Días de Atraso</p>
                    <p class="text-2xl font-bold text-gray-900">
                        <?php 
                        $avgDaysOverdue = array_sum(array_column($overdueCredits, 'days_overdue')) / count($overdueCredits);
                        echo round($avgDaysOverdue) . ' días';
                        ?>
                    </p>
                </div>
            </div>
        </div>
    <?php endif; ?>
</div>

<script>
function exportToExcel() {
    // Crear una tabla temporal
    let table = document.getElementById('overdueTable').cloneNode(true);
    
    // Convertir la tabla a CSV
    let csv = [];
    let rows = table.querySelectorAll('tr');
    
    for (let i = 0; i < rows.length; i++) {
        let row = [], cols = rows[i].querySelectorAll('td, th');
        
        for (let j = 0; j < cols.length; j++) {
            // Obtener el texto limpio de la celda
            let text = cols[j].textContent.trim();
            // Envolver el texto en comillas y escapar las comillas existentes
            row.push('"' + text.replace(/"/g, '""') + '"');
        }
        
        csv.push(row.join(','));
    }
    
    // Crear el blob y descargar
    let csvContent = csv.join('\n');
    let blob = new Blob([csvContent], { type: 'text/csv;charset=utf-8;' });
    let link = document.createElement("a");
    let url = URL.createObjectURL(blob);
    link.setAttribute("href", url);
    link.setAttribute("download", "cuotas_atrasadas_" + new Date().toISOString().slice(0,10) + ".csv");
    link.style.visibility = 'hidden';
    document.body.appendChild(link);
    link.click();
    document.body.removeChild(link);
}
</script>

<?php
    require_once 'templates/footer.php';
} catch (Exception $e) {
    error_log("Error en list_overdue.php: " . $e->getMessage());
    $errorMessage = "Ha ocurrido un error al cargar las cuotas atrasadas. Por favor, intente nuevamente.";
    require_once 'templates/header.php';
    echo "<div class='bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4' role='alert'>
            <p class='font-bold'>Error</p>
            <p>$errorMessage</p>
          </div>";
    require_once 'templates/footer.php';
}
?>