<?php
require_once 'config.php';
require_once 'db.php';

$id = isset($_POST['id']) ? intval($_POST['id']) : 0;
$amount = floatval($_POST['amount']);
$method = $_POST['method'] ?? '';
$notes = $_POST['notes'] ?? '';

try {
    $db = Database::getInstance()->getConnection();

    // Obtener datos de la cuota
    $stmt = $db->prepare("SELECT * FROM installments WHERE id = ?");
    $stmt->execute([$id]);
    $cuota = $stmt->fetch();

    if (!$cuota) {
        echo "Cuota no encontrada";
        exit;
    }

    // Calcular nuevo total pagado y estado
    $nuevoPagado = $cuota['amount_paid'] + $amount;
    $nuevoEstado = ($nuevoPagado >= $cuota['amount']) ? 'pagado' : 'parcial';

    // Registrar el pago en la tabla payments (AJUSTADO)
    $stmt = $db->prepare("INSERT INTO payments 
        (installment_id, credit_id, installment_number, payment_amount, method, notes, payment_date) 
        VALUES (?, ?, ?, ?, ?, ?, CURDATE())");

    $stmt->execute([
        $cuota['id'],
        $cuota['credit_id'],
        $cuota['installment_number'],
        $amount,
        $method,
        $notes
    ]);

    // Actualizar el estado de la cuota
    $stmt = $db->prepare("UPDATE installments SET amount_paid = ?, status = ? WHERE id = ?");
    $stmt->execute([$nuevoPagado, $nuevoEstado, $id]);

    // Redirigir al recibo
    header("Location: recibo_pago.php?installment_id=" . $id);
    exit;

} catch (Exception $e) {
    echo "Error: " . $e->getMessage();
}
