<?php
require_once 'config.php';
require_once 'db.php';
require_once 'dompdf/autoload.inc.php';

use Dompdf\Dompdf;
use Dompdf\Options;

ini_set('display_errors', 1);
error_reporting(E_ALL);

if (!isset($_GET['id'])) {
    die("ID de crédito no especificado");
}

$credit_id = intval($_GET['id']);

// Conexión mysqli
$conn = new mysqli(DB_HOST, DB_USER, DB_PASS, DB_NAME);
if ($conn->connect_error) {
    die("Error de conexión: " . $conn->connect_error);
}

$sql_credit = "
    SELECT cr.*, cu.name AS customer_name, cu.contact 
    FROM credits cr
    JOIN customers cu ON cu.id = cr.customer_id
    WHERE cr.id = $credit_id
";
$result_credit = $conn->query($sql_credit);
if (!$result_credit || $result_credit->num_rows == 0) {
    die("Crédito no encontrado");
}
$credit = $result_credit->fetch_assoc();

$sql_payments = "
    SELECT * FROM payments 
    WHERE credit_id = $credit_id 
    ORDER BY installment_number ASC
";
$result_payments = $conn->query($sql_payments);

$pagado = 0;
$total = $credit['total_amount'];
$fechaHoy = date('Y-m-d');

$html = '
<style>
    body { font-family: sans-serif; font-size: 12px; }
    h2 { text-align: center; margin: 0; }
    .logo { text-align: center; margin-bottom: 10px; }
    .logo img { max-width: 180px; }
    .info, .totales { margin-bottom: 10px; }
    .cuotas { width: 100%; border-collapse: collapse; margin-top: 15px; }
    .cuotas th, .cuotas td { border: 1px solid #ccc; padding: 5px; text-align: center; }
    .verde { background-color: #d4edda; }
    .naranja { background-color: #fff3cd; }
    .rojo { background-color: #f8d7da; }
</style>

<div class="logo">
    <img src="https://solotecno.com.ar/logo.jpg" alt="SoloTecno">
</div>

<h2>Reporte de Crédito</h2>

<div class="info">
    <strong>Cliente:</strong> ' . htmlspecialchars($credit['customer_name']) . '<br>
    <strong>Contacto:</strong> ' . htmlspecialchars($credit['contact']) . '<br>
    <strong>Producto:</strong> ' . htmlspecialchars($credit['product']) . '<br>
    <strong>Fecha de inicio:</strong> ' . $credit['start_date'] . '<br>
</div>

<table class="cuotas">
    <tr>
        <th>Cuota</th>
        <th>Fecha</th>
        <th>Monto</th>
        <th>Estado</th>
    </tr>';

while ($p = $result_payments->fetch_assoc()) {
    $fecha = $p['payment_date'];
    $monto = $p['payment_amount'];
    $pagado += $monto;

    if ($fecha <= $fechaHoy) {
        $estado = 'Pagada';
        $clase = 'verde';
    } else {
        $dias_dif = (strtotime($fechaHoy) - strtotime($fecha)) / (60*60*24);
        $estado = ($dias_dif < 0) ? 'Próxima' : 'Vencida';
        $clase = ($dias_dif < 0) ? 'naranja' : 'rojo';
    }

    $html .= '
    <tr class="' . $clase . '">
        <td>' . $p['installment_number'] . '</td>
        <td>' . $fecha . '</td>
        <td>$' . number_format($monto, 2, ',', '.') . '</td>
        <td>' . $estado . '</td>
    </tr>';
}

$saldo = $total - $pagado;
$num_cuotas = $credit['num_installments'];
$cuotas_pagadas = $result_payments->num_rows;
$cuotas_restantes = $num_cuotas - $cuotas_pagadas;

$html .= '
</table>

<div class="totales" style="margin-top: 15px;">
    <strong>Monto total:</strong> $' . number_format($total, 2, ',', '.') . '<br>
    <strong>Total pagado:</strong> $' . number_format($pagado, 2, ',', '.') . '<br>
    <strong>Saldo pendiente:</strong> $' . number_format($saldo, 2, ',', '.') . '<br><br>
    <strong>Cuotas totales:</strong> ' . $num_cuotas . '<br>
    <strong>Cuotas pagadas:</strong> ' . $cuotas_pagadas . '<br>
    <strong>Cuotas restantes:</strong> ' . $cuotas_restantes . '
</div>

<div style="margin-top: 50px;">
    ____________________________<br>
    Firma del cliente
</div>
';

$options = new Options();
$options->set('isRemoteEnabled', true);
$dompdf = new Dompdf($options);
$dompdf->loadHtml($html);
$dompdf->setPaper('A4', 'portrait');
$dompdf->render();
$dompdf->stream("reporte_credito_{$credit_id}.pdf", ["Attachment" => false]);
?>
