<?php
require_once 'config.php';
require_once 'db.php';

$db = Database::getInstance()->getConnection();

$where = "i.status != 'pagado' AND i.due_date < CURDATE()";
$params = [];

if (!empty($_GET['desde'])) {
    $where .= " AND i.due_date >= ?";
    $params[] = $_GET['desde'];
}
if (!empty($_GET['hasta'])) {
    $where .= " AND i.due_date <= ?";
    $params[] = $_GET['hasta'];
}

$stmt = $db->prepare("SELECT i.*, i.id as installment_id, c.product, cu.name, cu.contact
                      FROM installments i
                      JOIN credits c ON c.id = i.credit_id
                      JOIN customers cu ON cu.id = c.customer_id
                      WHERE $where
                      ORDER BY i.due_date ASC");
$stmt->execute($params);
$cuotas = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang='es'>
<head>
  <meta charset='UTF-8'>
  <title>Cuotas Vencidas</title>
  <script src='https://cdn.tailwindcss.com'></script>
</head>
<body class='bg-gray-100 p-6'>
    <nav class="sticky top-0 z-50 bg-[#004a80] text-center py-2 print:hidden mb-6">
  <a href="index.php" class="mx-2 px-4 py-2 bg-blue-700 text-white rounded hover:bg-blue-800">Inicio</a>
  <a href="simulacion.html" class="mx-2 px-4 py-2 bg-blue-700 text-white rounded hover:bg-blue-800">Simular Crédito</a>
  <a href="reporte_mora.php" class="mx-2 px-4 py-2 bg-blue-700 text-white rounded hover:bg-blue-800">Cuotas Vencidas</a>
  <a href="list_overdue.php" class="mx-2 px-4 py-2 bg-blue-700 text-white rounded hover:bg-blue-800">Créditos en Mora</a>
</nav>
<div class='max-w-6xl mx-auto bg-white p-6 rounded shadow'>
    <div class='flex justify-between items-center mb-4'>
        <h1 class='text-2xl font-bold'>Reporte de Cuotas Vencidas</h1>
        <button onclick='window.print()' class='bg-green-600 text-white px-4 py-2 rounded hover:bg-green-700'>Imprimir</button>
    </div>

    <form method="get" class="mb-6 flex gap-4 items-end">
        <div>
            <label class="block text-sm text-gray-700">Desde</label>
            <input type="date" name="desde" class="border rounded p-2" value="<?= htmlspecialchars($_GET['desde'] ?? '') ?>">
        </div>
        <div>
            <label class="block text-sm text-gray-700">Hasta</label>
            <input type="date" name="hasta" class="border rounded p-2" value="<?= htmlspecialchars($_GET['hasta'] ?? '') ?>">
        </div>
        <button type="submit" class="bg-blue-600 hover:bg-blue-700 text-white px-4 py-2 rounded">Filtrar</button>
    </form>

    <table class='w-full border border-gray-300 text-sm'>
        <thead class='bg-gray-200'>
            <tr>
                <th class='border p-2'>Cliente</th>
                <th class='border p-2'>Contacto</th>
                <th class='border p-2'>Producto</th>
                <th class='border p-2'>Cuota #</th>
                <th class='border p-2'>Vencimiento</th>
                <th class='border p-2'>Monto</th>
                <th class='border p-2'>Pagado</th>
                <th class='border p-2'>Estado</th>
                <th class='border p-2'>Días atraso</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($cuotas as $c): 
                $atraso = (new DateTime())->diff(new DateTime($c['due_date']))->days;
            ?>
            <tr class='text-center'>
                <td class='border p-2'><?= htmlspecialchars($c['name']) ?></td>
                <td class='border p-2'><?= htmlspecialchars($c['contact']) ?></td>
                <td class='border p-2'><?= htmlspecialchars($c['product']) ?></td>
                <td class='border p-2'><?= $c['installment_number'] ?></td>
                <td class='border p-2 text-red-600'><?= date('d/m/Y', strtotime($c['due_date'])) ?></td>
                <td class='border p-2'>$<?= number_format($c['amount'], 2, ',', '.') ?></td>
                <td class='border p-2'>$<?= number_format($c['amount_paid'], 2, ',', '.') ?></td>
                <td class='border p-2'>
                    <?php if ($c['status'] === 'parcial'): ?>
                        <span class='text-yellow-600 font-semibold'>Parcial</span>
                    <?php else: ?>
                        <span class='text-red-600 font-semibold'>Pendiente</span>
                    <?php endif; ?>
                </td>
                <td class='border p-2 text-sm'><?= $atraso ?></td>
            </tr>
            <?php endforeach; ?>
        </tbody>
    </table>

    <?php if (empty($cuotas)): ?>
        <p class='text-center text-gray-500 mt-6'>No hay cuotas vencidas para el período seleccionado.</p>
    <?php endif; ?>
</div>
</body>
</html>
