
<?php
require_once 'config.php';
require_once 'db.php';
require_once 'functions.php';

$creditId = isset($_GET['id']) ? intval($_GET['id']) : 0;

try {
    $db = Database::getInstance()->getConnection();

    $stmt = $db->prepare("SELECT c.*, cu.name, cu.contact FROM credits c JOIN customers cu ON c.customer_id = cu.id WHERE c.id = ?");
    $stmt->execute([$creditId]);
    $credito = $stmt->fetch();

    if (!$credito) {
        echo "Crédito no encontrado.";
        exit;
    }

    $stmt = $db->prepare("SELECT * FROM installments WHERE credit_id = ? ORDER BY installment_number ASC");
    $stmt->execute([$creditId]);
    $cuotas = $stmt->fetchAll();

} catch (Exception $e) {
    echo "Error: " . $e->getMessage();
    exit;
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Detalle de Cuotas</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <style>
    @media print {
        .no-print { display: none !important; }
        .print-only { display: block !important; }
        .tabla-cuotas td, .tabla-cuotas th { font-size: 10px !important; padding: 2px !important; }
        body { background: white !important; margin: 0; padding: 0; }
    }
    </style>
</head>
<body class="bg-gray-100 p-6">
    <div class="max-w-6xl mx-auto bg-white p-6 rounded shadow">
        <div class="flex justify-between items-center mb-6">
            <h1 class="text-2xl font-bold text-gray-800">
                Detalle del Préstamo #<?php echo $credito['id']; ?>
            </h1>
            <div class="flex gap-2 no-print">
                <a href="index.php" class="bg-gray-600 hover:bg-gray-700 text-white px-4 py-2 rounded transition-colors">
                    Volver
                </a>
                <a href="reporte_cliente_pdf.php?id=<?php echo $credito['id']; ?>" target="_blank" class="bg-blue-600 hover:bg-blue-700 text-white px-4 py-2 rounded transition-colors">
                    Exportar PDF
                </a>
                <button onclick="window.print()" class="bg-green-600 hover:bg-green-700 text-white px-4 py-2 rounded">
                    Imprimir Cronograma
                </button>
            </div>
        </div>

        <div class="print-only mb-4 flex items-center gap-4">
            <img src="logo.jpg" alt="SoloTecno" style="height: 60px;">
            <h2 class="text-xl font-bold">Cronograma de Pagos</h2>
        </div>

        <div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-6">
            <div>
                <p class="text-sm text-gray-600">Cliente:</p>
                <p class="text-lg font-semibold text-gray-800"><?php echo htmlspecialchars($credito['name']); ?></p>
            </div>
            <div>
                <p class="text-sm text-gray-600">Contacto:</p>
                <p class="text-lg font-semibold text-gray-800"><?php echo htmlspecialchars($credito['contact']); ?></p>
            </div>
            <div>
                <p class="text-sm text-gray-600">Producto:</p>
                <p class="text-lg font-semibold text-gray-800"><?php echo htmlspecialchars($credito['product']); ?></p>
            </div>
            <div>
                <p class="text-sm text-gray-600">Monto Total:</p>
                <p class="text-lg font-semibold text-gray-800">$<?php echo number_format($credito['total_amount'], 2, ',', '.'); ?></p>
            </div>
        </div>

        <?php
        $total = count($cuotas);
        $pagadas = array_filter($cuotas, fn($c) => $c['status'] === 'pagado');
        $pendientes = $total - count($pagadas);
        ?>
        <div class="grid grid-cols-2 md:grid-cols-4 gap-4 mb-4 text-sm">
            <div class="bg-gray-200 p-2 rounded text-center">Total Cuotas: <strong><?php echo $total; ?></strong></div>
            <div class="bg-green-200 p-2 rounded text-center">Pagadas: <strong><?php echo count($pagadas); ?></strong></div>
            <div class="bg-yellow-100 p-2 rounded text-center">Parciales:
                <strong><?php echo count(array_filter($cuotas, fn($c) => $c['amount_paid'] > 0 && $c['status'] !== 'pagado')); ?></strong>
            </div>
            <div class="bg-red-200 p-2 rounded text-center">Pendientes: <strong><?php echo $pendientes; ?></strong></div>
        </div>

        <h2 class="text-xl font-semibold text-gray-800 mb-3">Cuotas</h2>
        <div class="overflow-x-auto">
            <table class="min-w-full border border-gray-300 text-sm tabla-cuotas">
                <thead class="bg-gray-100">
                    <tr>
                        <th class="border p-2">#</th>
                        <th class="border p-2">Fecha</th>
                        <th class="border p-2">Monto</th>
                        <th class="border p-2">Pagado</th>
                        <th class="border p-2">Estado</th>
                        <th class="border p-2">Acción</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($cuotas as $cuota): ?>
                    <tr class="text-center hover:bg-gray-50">
                        <td class="border p-2"><?php echo $cuota['installment_number']; ?></td>
                        <td class="border p-2"><?php echo date('d/m/Y', strtotime($cuota['due_date'])); ?></td>
                        <td class="border p-2">$<?php echo number_format($cuota['amount'], 2, ',', '.'); ?></td>
                        <td class="border p-2">$<?php echo number_format($cuota['amount_paid'], 2, ',', '.'); ?></td>
                        <td class="border p-2">
                            <?php if ($cuota['status'] === 'pagado'): ?>
                                <span class="text-green-600 font-bold">Pagado</span>
                            <?php elseif ($cuota['amount_paid'] > 0): ?>
                                <span class="text-yellow-600 font-bold">Parcial</span>
                            <?php else: ?>
                                <span class="text-red-600 font-bold">Pendiente</span>
                            <?php endif; ?>
                        </td>
                        <td class="border p-2 text-xs">
                            <a href="registrar_pago.php?id=<?php echo $cuota['id']; ?>" class="inline-block bg-indigo-600 hover:bg-indigo-700 text-white px-2 py-1 rounded">
                                Registrar Pago
                            </a>
                        </td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>
</html>
